@@ -1,6 +1,5 @@
-from arch_lint.dag.core import (
-    DAG,
-    new_dag,
+from arch_lint.dag import (
+    DagMap,
 )
 from arch_lint.graph import (
     FullPathModule,
@@ -16,16 +15,22 @@ _dag: Dict[str, Tuple[Union[Tuple[str, ...], str], ...]] = {
     "arch_lint": (
         ("dag", "forbidden", "private"),
         "graph",
+        "_full_path",
+        "_utils",
     ),
     "arch_lint.dag": (
         "check",
-        "core",
+        "_dag_map",
+        "_dag",
     ),
 }
 
 
-def project_dag() -> DAG:
-    return new_dag(_dag)
+def project_dag() -> DagMap:
+    result = DagMap.new(_dag)
+    if isinstance(result, Exception):
+        raise result
+    return result
 
 
 def forbidden_allowlist() -> Dict[FullPathModule, FrozenSet[FullPathModule]]:
@@ -33,8 +38,8 @@ def forbidden_allowlist() -> Dict[FullPathModule, FrozenSet[FullPathModule]]:
         "grimp": frozenset(["arch_lint.graph"]),
     }
     return {
-        FullPathModule.from_raw(k): frozenset(
-            FullPathModule.from_raw(i) for i in v
+        FullPathModule.assert_module(k): frozenset(
+            FullPathModule.assert_module(i) for i in v
         )
         for k, v in _raw.items()
     }
