@@ -1,6 +1,5 @@
-from arch_lint.dag.core import (
-    DAG,
-    new_dag,
+from arch_lint.dag import (
+    DagMap,
 )
 from arch_lint.graph import (
     FullPathModule,
@@ -27,15 +26,18 @@ _dag: Dict[str, Tuple[Union[Tuple[str, ...], str], ...]] = {
 }
 
 
-def project_dag() -> DAG:
-    return new_dag(_dag)
+def project_dag() -> DagMap:
+    result = DagMap.new(_dag)
+    if isinstance(result, Exception):
+        raise result
+    return result
 
 
 def forbidden_allowlist() -> Dict[FullPathModule, FrozenSet[FullPathModule]]:
     _raw: Dict[str, FrozenSet[str]] = {}
     return {
-        FullPathModule.from_raw(k): frozenset(
-            FullPathModule.from_raw(i) for i in v
+        FullPathModule.assert_module(k): frozenset(
+            FullPathModule.assert_module(i) for i in v
         )
         for k, v in _raw.items()
     }
